Class: PictureTag::Instructions::ConditionalInstruction
- Inherits:
-
Instruction
- Object
- Instruction
- PictureTag::Instructions::ConditionalInstruction
- Defined in:
- lib/jekyll_picture_tag/instructions/parents/conditional_instruction.rb
Overview
Many inputs take a common format: a generic setting which applies all of the time, or more specific versions of that setting for specific circumstances. For example, quality can be set globally, or per image format. This instruction class handles those cases.
To use, you must at minimum define setting_basename, setting_prefix, and add to the acceptable_types (or write your own validation).
Instance Method Summary collapse
Instance Method Details
#value(*args) ⇒ Object
11 12 13 |
# File 'lib/jekyll_picture_tag/instructions/parents/conditional_instruction.rb', line 11 def value(*args) coerce(*args) end |