Class: PictureTag::Instructions::EnvInstruction

Inherits:
Instruction
  • Object
show all
Defined in:
lib/jekyll_picture_tag/instructions/parents/env_instruction.rb

Overview

There are a few config settings which are environment dependent, and can either be booleans, environment names, or arrays of environment names. This class works it out and returns a boolean.

Direct Known Subclasses

Cdn, ContinueOnMissing, Disabled, FastBuild, RelativeUrl

Method Summary

Methods inherited from Instruction

#value